/* General CSS */
body {
    margin: 0;
    font-family: sans-serif;
}

.button {
    padding: 0.5rem 1rem;
    background: steelblue;
    color: white;
}

/* Media query with a nested @supports */
@media (max-width: 600px) {
    body {
        font-size: 14px;
    }

    @supports (display: grid) {
        .grid {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
        }
    }
}
